"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const PluginStrictFileChecker_1 = require("./PluginStrictFileChecker");
const utils_1 = require("./utils");
const init = ({ typescript }) => {
    function create(info) {
        const proxy = (0, utils_1.setupLanguageServiceProxy)(info);
        const strictLanguageServiceHost = (0, utils_1.setupStrictLanguageServiceHostProxy)(info);
        const strictLanguageService = typescript.createLanguageService(strictLanguageServiceHost);
        (0, utils_1.log)(info, 'Plugin initialized');
        proxy.getSemanticDiagnostics = function (filePath) {
            const strictFile = new PluginStrictFileChecker_1.PluginStrictFileChecker(info).isFileStrict(filePath);
            if (strictFile) {
                return strictLanguageService.getSemanticDiagnostics(filePath);
            }
            else {
                return info.languageService.getSemanticDiagnostics(filePath);
            }
        };
        proxy.cleanupSemanticCache = function () {
            strictLanguageService.cleanupSemanticCache();
            info.languageService.cleanupSemanticCache();
        };
        proxy.dispose = function () {
            strictLanguageService.dispose();
            info.languageService.dispose();
        };
        proxy.getQuickInfoAtPosition = function (filePath, position) {
            const strictFile = new PluginStrictFileChecker_1.PluginStrictFileChecker(info).isFileStrict(filePath);
            if (strictFile) {
                return strictLanguageService.getQuickInfoAtPosition(filePath, position);
            }
            else {
                return info.languageService.getQuickInfoAtPosition(filePath, position);
            }
        };
        return proxy;
    }
    return { create };
};
module.exports = init;
